/// <reference types="node" />
import * as fs from 'fs';
import { ParsedCommandLine } from 'typescript';
import { Config, TsProject } from './types';
declare const promisified: {
    fs: any;
    fse: any;
    rimraf: any;
};
declare const console_colors: {
    readonly Reset: "\u001B[0m";
    readonly Bright: "\u001B[1m";
    readonly Dim: "\u001B[2m";
    readonly Underscore: "\u001B[4m";
    readonly Blink: "\u001B[5m";
    readonly Reverse: "\u001B[7m";
    readonly Hidden: "\u001B[8m";
    readonly FgBlack: "\u001B[30m";
    readonly FgRed: "\u001B[31m";
    readonly FgGreen: "\u001B[32m";
    readonly FgYellow: "\u001B[33m";
    readonly FgBlue: "\u001B[34m";
    readonly FgMagenta: "\u001B[35m";
    readonly FgCyan: "\u001B[36m";
    readonly FgWhite: "\u001B[37m";
    readonly BgBlack: "\u001B[40m";
    readonly BgRed: "\u001B[41m";
    readonly BgGreen: "\u001B[42m";
    readonly BgYellow: "\u001B[43m";
    readonly BgBlue: "\u001B[44m";
    readonly BgMagenta: "\u001B[45m";
    readonly BgCyan: "\u001B[46m";
    readonly BgWhite: "\u001B[47m";
    readonly FgBrightBlack: "\u001B[90m";
    readonly FgBrightRed: "\u001B[91m";
    readonly FgBrightGreen: "\u001B[92m";
    readonly FgBrightYellow: "\u001B[93m";
    readonly FgBrightBlue: "\u001B[94m";
    readonly FgBrightMagenta: "\u001B[95m";
    readonly FgBrightCyan: "\u001B[96m";
    readonly FgBrightWhite: "\u001B[97m";
    readonly BgBrightBlack: "\u001B[100m";
    readonly BgBrightRed: "\u001B[101m";
    readonly BgBrightGreen: "\u001B[102m";
    readonly BgBrightYellow: "\u001B[103m";
    readonly BgBrightBlue: "\u001B[104m";
    readonly BgBrightMagenta: "\u001B[105m";
    readonly BgBrightCyan: "\u001B[106m";
    readonly BgBrightWhite: "\u001B[107m";
};
/**
 * Returns the complete, resolved configuration object
 */
declare function get_config(): Promise<Config>;
/**
 * Finds the `project` config file in `currentDir` and parses it with Typescript's own parser
 * @param currentDir
 * @param project
 */
declare function get_ts_config(currentDir: string, project: string): ParsedCommandLine;
/**
 * Returns the internal project descriptor of a TS project that doesn't have project references
 * @param options
 */
declare function get_ts_project_paths(options: Config): TsProject;
/**
 * Returns the internal project descriptor of a TS project that has project references
 * @param options
 */
declare function get_ts_projects_paths(options: Config): TsProject[];
/**
 * Displays a colored log in the stdout
 * @param msg
 * @param color
 */
declare function color_log(msg: string, color: typeof console_colors[keyof typeof console_colors]): string;
/**
 * Makes sure that the given folder (or the parent folder of a file) exists - creates if not
 * @param p {string}
 */
declare function validate_path(p: string): Promise<void>;
/**
 * Error-safe `fs.lstat` - returns stats if the file exists, otherwise null
 * @param file_path
 */
declare function get_file_stats(file_path: string): Promise<fs.Stats | void>;
/**
 * Deletes the `file_path` file. Doesn't throw error if the file doesn't exist.
 * @param file_path
 */
declare function remove_file_or_directory(file_path: string): Promise<void>;
/**
 * Reads the content of the `source_path` file, applies the loaders on its content, and writes the processed content to `destination_path`
 * @param source_path
 * @param destination_path
 * @param config
 */
declare function copy_file_or_directory(source_path: string, destination_path: string, config: Config): Promise<any>;
/**
 * Returns a Promise that resolves automatically after `ms`
 * @param ms
 */
declare function sleep(ms: any): Promise<unknown>;
export { get_config, get_ts_config, get_ts_project_paths, get_ts_projects_paths, validate_path, get_file_stats, remove_file_or_directory, copy_file_or_directory, sleep, promisified, console_colors, color_log, };
